<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.force24.co.uk/
 * @since      1.0.0
 *
 * @package    Force24_Tracking
 * @subpackage Force24_Tracking/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Force24_Tracking
 * @subpackage Force24_Tracking/public
 * @author     Force24 Ltd <jm@force24.co.uk>
 */
class Force24_Tracking_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct( $plugin_name, $version ) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;

    }

    /**
     * Show the tracking code for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function show_tracking() {

        /**
         * An instance of this class should be passed to the run() function
         * defined in Force24_Tracking_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Force24_Tracking_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        $options = get_option('force24_tracking');

        // load client ID
        if (!isset($options['client_id']) || !$options['client_id']) {
            return false;
        }

        ?>
        <!-- Start Force24 tracking -->
        <script>
            !function(f,o,r,c,e,_2,_4){f.Force24Object=e,f[e]=f[e]||function(){
                (f[e].q=f[e].q||[]).push(arguments)},f[e].l=1*new Date,
                _2=o.createElement(r),_4=o.getElementsByTagName(r)[0],_2.async=1,
                _2.src=c,_4.parentNode.insertBefore(_2,_4)}(window,document,
                "script","//tracking1.force24.co.uk/tracking/V2/main.min.js","f24");

            f24("create", "<?php echo $options['client_id']; ?>");
            <?php
            if (isset($options['form_selector']) && $options['form_selector']) {
            ?>
            f24("formSelector", "<?php echo $options['form_selector']; ?>");
            <?php
            }
            ?>
            f24("cookieAnonymous", <?php echo (isset($options['cookie_anonymous']) && $options['cookie_anonymous']) ? 'true' : 'false'; ?>);
            f24("cookieOnFormSubmit", <?php echo ((isset($options['cookie_on_form_submit']) && $options['cookie_on_form_submit']) || !isset($options['cookie_on_form_submit'])) ? 'true' : 'false'; ?>);
            <?php
            if (isset($options['cookie_domain']) && $options['cookie_domain']) {
            ?>
            f24("cookieDomain", "<?php echo $options['cookie_domain']; ?>");
            <?php
            }
            ?>
            f24("trackExternalLinks", <?php echo (isset($options['track_external_links']) && $options['track_external_links']) ? 'true' : 'false'; ?>);
            f24("formSubmitAfterTracking", <?php echo ((isset($options['form_submit_after_tracking']) && $options['form_submit_after_tracking']) || !isset($options['form_submit_after_tracking'])) ? 'true' : 'false'; ?>);
            f24("appendGuidExternal", <?php echo (isset($options['append_guid_external']) && $options['append_guid_external']) ? 'true' : 'false'; ?>);
            f24("trackPushState", <?php echo (isset($options['track_push_state']) && $options['track_push_state']) ? 'true' : 'false'; ?>);
            f24("send", "pageview");
            <?php
            if (isset($options['form_maps']) && $options['form_maps']) {
            ?>
            f24("formMap", <?php echo $options['form_maps']; ?>);
            <?php
            }
            ?>
            <?php
            if ( $this->is_plugin_active( 'contact-form-7/wp-contact-form-7.php' ) ) {
            ?>
            // Contact Form 7 support
            var wpcf7Elm = document.querySelector('.wpcf7');
            wpcf7Elm.addEventListener( 'wpcf7mailsent', function( event ) {

                // force disable submitAfterTracking for CF7 forms
                var original = f24("settings").form.submitAfterTracking;
                f24("formSubmitAfterTracking", false);

                f24("send", "form", jQuery(this).find("form"), function () {
                    f24("formSubmitAfterTracking", original);
                });
            }, false );
            <?php
            }
            if ( $this->is_plugin_active( 'ninja-forms/ninja-forms.php' ) ) {
            ?>
            // Ninja Forms support
            f24.ninjaForms = function () {
                var $ = f24("jQuery");
                // Wait for jQuery, Marionette and Backbone Radio
                if (!$ || !f24("settings").form.selector
                    || typeof Marionette === "undefined"
                    || typeof Backbone === "undefined"
                    || !Backbone.Radio
                ) {
                    setTimeout(f24.ninjaForms, 500);
                    return false;
                }
                var f24NinjaFormsSubmitController = Marionette.Object.extend({
                    initialize: function() {
                        // listen to all Ninja Forms submissions
                        this.listenTo(Backbone.Radio.channel('forms'), 'submit:response', this.actionSubmit);
                    },

                    actionSubmit: function(response) {
                        // If the form came back with any errors, don't attempt to capture.
                        if (response.errors.length) {
                            return;
                        }
                        // capture the form that had been submitted
                        var $form = $("#nf-form-" + response.data.form_id + "-cont form");
                        f24("send", "form", $form);
                    },
                });

                $(document).ready(function($) {
                    // Instantiate our custom form controller, defined above.
                    new f24NinjaFormsSubmitController();
                });
            };
            f24.ninjaForms();
            <?php
            }
            ?>
        </script>
        <!-- End Force24 tracking -->
        <?php

    }

    protected function is_plugin_active( $plugin ) {
        return in_array( $plugin, (array) get_option( 'active_plugins', array() ) );
    }

}
